@@ -1536,40 +1536,3 @@ class MultirotorClient(VehicleClient, object):
         """ Disables race log """
         self.client.call('simDisableRaceLog')
 
-
-# -----------------------------------  Car APIs ---------------------------------------------
-class CarClient(VehicleClient, object):
-    def __init__(self, ip = "", port = 41451, timeout_value = 3600):
-        super(CarClient, self).__init__(ip, port, timeout_value)
-
-    def setCarControls(self, controls, vehicle_name = ''):
-        """
-        Control the car using throttle, steering, brake, etc.
-
-        Args:
-            controls (CarControls): Struct containing control values
-            vehicle_name (str, optional): Name of vehicle to be controlled
-        """
-        self.client.call('setCarControls', controls, vehicle_name)
-
-    def getCarState(self, vehicle_name = ''):
-        """
-        Args:
-            vehicle_name (str, optional): Name of vehicle
-
-        Returns:
-            CarState:
-        """
-        state_raw = self.client.call('getCarState', vehicle_name)
-        return CarState.from_msgpack(state_raw)
-
-    def getCarControls(self, vehicle_name=''):
-        """
-        Args:
-            vehicle_name (str, optional): Name of vehicle
-
-        Returns:
-            CarControls:
-        """
-        controls_raw = self.client.call('getCarControls', vehicle_name)
-        return CarControls.from_msgpack(controls_raw)
